SymbolicVmCalls

Enum SymbolicVmCalls 

pub enum SymbolicVmCalls {
Show 107 variants createAddress(createAddressCall), createBool(createBoolCall), createBytes_0(createBytes_0Call), createBytes_1(createBytes_1Call), createCalldata(createCalldataCall), createInt(createIntCall), createString_0(createString_0Call), createString_1(createString_1Call), createUint(createUintCall), enableSymbolicStorage(enableSymbolicStorageCall), snapshotStorage(snapshotStorageCall), createUint8(createUint8Call), createUint16(createUint16Call), createUint24(createUint24Call), createUint32(createUint32Call), createUint40(createUint40Call), createUint48(createUint48Call), createUint56(createUint56Call), createUint64(createUint64Call), createUint72(createUint72Call), createUint80(createUint80Call), createUint88(createUint88Call), createUint96(createUint96Call), createUint104(createUint104Call), createUint112(createUint112Call), createUint120(createUint120Call), createUint128(createUint128Call), createUint136(createUint136Call), createUint144(createUint144Call), createUint152(createUint152Call), createUint160(createUint160Call), createUint168(createUint168Call), createUint176(createUint176Call), createUint184(createUint184Call), createUint192(createUint192Call), createUint200(createUint200Call), createUint208(createUint208Call), createUint216(createUint216Call), createUint224(createUint224Call), createUint232(createUint232Call), createUint240(createUint240Call), createUint248(createUint248Call), createUint256(createUint256Call), createInt8(createInt8Call), createInt16(createInt16Call), createInt24(createInt24Call), createInt32(createInt32Call), createInt40(createInt40Call), createInt48(createInt48Call), createInt56(createInt56Call), createInt64(createInt64Call), createInt72(createInt72Call), createInt80(createInt80Call), createInt88(createInt88Call), createInt96(createInt96Call), createInt104(createInt104Call), createInt112(createInt112Call), createInt120(createInt120Call), createInt128(createInt128Call), createInt136(createInt136Call), createInt144(createInt144Call), createInt152(createInt152Call), createInt160(createInt160Call), createInt168(createInt168Call), createInt176(createInt176Call), createInt184(createInt184Call), createInt192(createInt192Call), createInt200(createInt200Call), createInt208(createInt208Call), createInt216(createInt216Call), createInt224(createInt224Call), createInt232(createInt232Call), createInt240(createInt240Call), createInt248(createInt248Call), createInt256(createInt256Call), createBytes1(createBytes1Call), createBytes2(createBytes2Call), createBytes3(createBytes3Call), createBytes4(createBytes4Call), createBytes5(createBytes5Call), createBytes6(createBytes6Call), createBytes7(createBytes7Call), createBytes8(createBytes8Call), createBytes9(createBytes9Call), createBytes10(createBytes10Call), createBytes11(createBytes11Call), createBytes12(createBytes12Call), createBytes13(createBytes13Call), createBytes14(createBytes14Call), createBytes15(createBytes15Call), createBytes16(createBytes16Call), createBytes17(createBytes17Call), createBytes18(createBytes18Call), createBytes19(createBytes19Call), createBytes20(createBytes20Call), createBytes21(createBytes21Call), createBytes22(createBytes22Call), createBytes23(createBytes23Call), createBytes24(createBytes24Call), createBytes25(createBytes25Call), createBytes26(createBytes26Call), createBytes27(createBytes27Call), createBytes28(createBytes28Call), createBytes29(createBytes29Call), createBytes30(createBytes30Call), createBytes31(createBytes31Call), createBytes32(createBytes32Call),
}
Container for all the SymbolicVm function calls.

Variants



createAddress(createAddressCall)



createBool(createBoolCall)



createBytes_0(createBytes_0Call)



createBytes_1(createBytes_1Call)



createCalldata(createCalldataCall)



createInt(createIntCall)



createString_0(createString_0Call)



createString_1(createString_1Call)



createUint(createUintCall)



enableSymbolicStorage(enableSymbolicStorageCall)



snapshotStorage(snapshotStorageCall)



createUint8(createUint8Call)



createUint16(createUint16Call)



createUint24(createUint24Call)



createUint32(createUint32Call)



createUint40(createUint40Call)



createUint48(createUint48Call)



createUint56(createUint56Call)



createUint64(createUint64Call)



createUint72(createUint72Call)



createUint80(createUint80Call)



createUint88(createUint88Call)



createUint96(createUint96Call)



createUint104(createUint104Call)



createUint112(createUint112Call)



createUint120(createUint120Call)



createUint128(createUint128Call)



createUint136(createUint136Call)



createUint144(createUint144Call)



createUint152(createUint152Call)



createUint160(createUint160Call)



createUint168(createUint168Call)



createUint176(createUint176Call)



createUint184(createUint184Call)



createUint192(createUint192Call)



createUint200(createUint200Call)



createUint208(createUint208Call)



createUint216(createUint216Call)



createUint224(createUint224Call)



createUint232(createUint232Call)



createUint240(createUint240Call)



createUint248(createUint248Call)



createUint256(createUint256Call)



createInt8(createInt8Call)



createInt16(createInt16Call)



createInt24(createInt24Call)



createInt32(createInt32Call)



createInt40(createInt40Call)



createInt48(createInt48Call)



createInt56(createInt56Call)



createInt64(createInt64Call)



createInt72(createInt72Call)



createInt80(createInt80Call)



createInt88(createInt88Call)



createInt96(createInt96Call)



createInt104(createInt104Call)



createInt112(createInt112Call)



createInt120(createInt120Call)



createInt128(createInt128Call)



createInt136(createInt136Call)



createInt144(createInt144Call)



createInt152(createInt152Call)



createInt160(createInt160Call)



createInt168(createInt168Call)



createInt176(createInt176Call)



createInt184(createInt184Call)



createInt192(createInt192Call)



createInt200(createInt200Call)



createInt208(createInt208Call)



createInt216(createInt216Call)



createInt224(createInt224Call)



createInt232(createInt232Call)



createInt240(createInt240Call)



createInt248(createInt248Call)



createInt256(createInt256Call)



createBytes1(createBytes1Call)



createBytes2(createBytes2Call)



createBytes3(createBytes3Call)



createBytes4(createBytes4Call)



createBytes5(createBytes5Call)



createBytes6(createBytes6Call)



createBytes7(createBytes7Call)



createBytes8(createBytes8Call)



createBytes9(createBytes9Call)



createBytes10(createBytes10Call)



createBytes11(createBytes11Call)



createBytes12(createBytes12Call)



createBytes13(createBytes13Call)



createBytes14(createBytes14Call)



createBytes15(createBytes15Call)



createBytes16(createBytes16Call)



createBytes17(createBytes17Call)



createBytes18(createBytes18Call)



createBytes19(createBytes19Call)



createBytes20(createBytes20Call)



createBytes21(createBytes21Call)



createBytes22(createBytes22Call)



createBytes23(createBytes23Call)



createBytes24(createBytes24Call)



createBytes25(createBytes25Call)



createBytes26(createBytes26Call)



createBytes27(createBytes27Call)



createBytes28(createBytes28Call)



createBytes29(createBytes29Call)



createBytes30(createBytes30Call)



createBytes31(createBytes31Call)



createBytes32(createBytes32Call)

Implementations

Source

impl SymbolicVmCalls

pub const SELECTORS: &'static [[u8; 4]]

All the selectors of this enum.

Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.

Prefer using SolInterface methods instead.

pub const VARIANT_NAMES: &'static [&'static str]

The names of the variants in the same order as SELECTORS.

pub const SIGNATURES: &'static [&'static str]

The signatures in the same order as SELECTORS.

pub fn signature_by_selector(selector: [u8; 4]) -> Option<&'static str>

Returns the signature for the given selector, if known.

pub fn name_by_selector(selector: [u8; 4]) -> Option<&'static str>

Returns the enum variant name for the given selector, if known.